@@ -7,11 +7,15 @@ from forge_sdk.protos import protos
 logger = logging.getLogger('rpc-poke')
 
 
-def build_transfer_itx(to, value=None, assets=None, data=None):
-    value = utils.value_to_biguint(value)
-    return utils.encode_to_any(
+def build_transfer_itx(to, value=None, assets=None, data=None, encoded=True):
+    itx = protos.TransferTx(to=to,
+                            value=utils.int_to_biguint(value),
+                            assets=assets,
+                            data=data)
+    res = utils.encode_to_any(
         type_url="fg:t:transfer",
-        data=protos.TransferTx(**locals()))
+        data=itx) if encoded else itx
+    return res
 
 
 def build_transfer_tx(**kwargs):
@@ -19,7 +23,8 @@ def build_transfer_tx(**kwargs):
         to=kwargs.get('to'),
         value=kwargs.get('value'),
         assets=kwargs.get('assets'),
-        data=kwargs.get('data')
+        data=kwargs.get('data'),
+        encoded=True
     )
     return lib.build_unsigned_tx(itx=transfer_itx,
                                  nonce=1,
